import ms from 'pretty-ms';
import React, { useEffect, useState } from 'react';
import { dispatch, useRoundSeconds } from '../../../../domain/gameStore';
import styles from './GuessPane.module.css';

const useRoundTimer = (onTimeout) => {
  const remaining = useRoundSeconds();
  useEffect(
    () => {
      if (remaining > 0) {
        const timeout = setTimeout(() => {
          dispatch.setRoundSeconds(remaining - 1);
        }, 1000);
        return () => clearTimeout(timeout);
      }
    },
    [ remaining ]
  );
  const [ called, setCalled ] = useState(false);
  useEffect(
    () => {
      if (!called && remaining <= 0) {
        onTimeout();
        setCalled(true);
      }
    },
    [ onTimeout, remaining, called ]
  );
  return remaining;
};

export default ({ onTimeout }) => {
  const remaining = useRoundTimer(onTimeout);
  const out = remaining <= 0;
  return (
    <span className={`${styles.timer} ${out ? styles['timer--timeout'] : ''}`}>
      {out ? "Time's up!" : `Time: ${ms(remaining * 1000)}`}
    </span>
  );
};
